InterpolateConfig class

config for interpolate function Extrapolate clamp ,identity or extend from left or right inputRange is the list from which the current value is interpolated outputRange is the list from which the output value is selected and returned

Constructors

InterpolateConfig(List<double> inputRange, List<double> outputRange, {Extrapolate extrapolate = Extrapolate.EXTEND, Extrapolate? extrapolateLeft, Extrapolate? extrapolateRight})

Properties

extrapolate ↔ Extrapolate
getter/setter pair
extrapolateLeft ↔ Extrapolate?
getter/setter pair
extrapolateRight ↔ Extrapolate?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputRange ↔ List<double>
getter/setter pair
outputRange ↔ List<double>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited